@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.47.2.1.2.27 $
+// $Revision: 1.47.2.1.2.28 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -108,7 +108,7 @@ function xnpbookGetListBlock( $item_basic ) {
   // set to template
   global $xoopsTpl;
 
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // - copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -130,7 +130,7 @@ function xnpbookGetDetailBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
   $tpl->assign( 'editable', xnp_get_item_permission( $_SESSION['XNPSID'], $item_id, OP_MODIFY ) );
@@ -165,7 +165,7 @@ function xnpbookGetPrinterFriendlyDetailBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
   $tpl->assign( 'basic', $basic );
@@ -200,7 +200,7 @@ function xnpbookGetRegisterBlock() {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
   $tpl->assign( 'basic', $basic );
@@ -241,7 +241,7 @@ function xnpbookGetEditBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
   $tpl->assign( 'basic', $basic );
@@ -297,7 +297,7 @@ function xnpbookGetConfirmBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
   $tpl->assign( 'basic', $basic );
@@ -486,7 +486,7 @@ function xnpbookGetAdvancedSearchBlock( &$search_var ) {
   // set to template
   global $xoopsTpl;
 
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   $tpl->assign( $xoopsTpl->get_template_vars() );
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( 'basic', $basic );
