@@ -1,5 +1,5 @@
-<?php
-// $Revision: 1.57.2.1.2.23 $
+k<?php
+// $Revision: 1.57.2.1.2.24 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -106,7 +106,7 @@ function xnpdataGetListBlock( $item_basic ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -137,7 +137,7 @@ function xnpdataGetDetailBlock( $item_id ) {
   }
 
   // set to template
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -180,7 +180,7 @@ function xnpdataGetPrinterFriendlyDetailBlock( $item_id ) {
   }
 
   // set to template
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   $tpl->assign( $xoopsTpl->get_template_vars() );
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( 'editable', xnp_get_item_permission( $_SESSION['XNPSID'], $item_id, OP_MODIFY ) );
@@ -225,7 +225,7 @@ function xnpdataGetRegisterBlock() {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -278,7 +278,7 @@ function xnpdataGetEditBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -345,7 +345,7 @@ function xnpdataGetConfirmBlock( $item_id ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
@@ -630,7 +630,7 @@ function xnpdataGetAdvancedSearchBlock( &$search_var ) {
 
   // set to template
   global $xoopsTpl;
-  $tpl = new xoopsTpl();
+  $tpl = new XoopsTpl();
   // copy variables in $xoopsTpl to $tpl
   $tpl->assign( $xoopsTpl->get_template_vars() );
 
