@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.2.5 $
+// $Revision: 1.1.2.6 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -276,7 +276,7 @@ class XooNIpsUtilityUnzip extends XooNIpsUtility {
     case 0:
       // not compressed
       while ( ! feof( $this->_zfhandle ) && $size > 0 ) {
-        $buf = fread( $this->_zfhandle, min( $size, $unit ) );
+        $buf = fread( $this->_zfhandle, $unit );
         if ( $buf === false ) {
           fclose( $ofh );
           unlink( $filepath );
@@ -315,7 +315,7 @@ class XooNIpsUtilityUnzip extends XooNIpsUtility {
       // OS(unknown)
       fwrite( $tfh, "\xff" );
       while ( ! feof( $this->_zfhandle ) && $size > 0 ) {
-        $buf = fread( $this->_zfhandle, min( $size, $unit ) );
+        $buf = fread( $this->_zfhandle, $unit );
         if ( $buf === false ) {
           fclose( $tfh );
           unlink( $tfn );
@@ -347,7 +347,7 @@ class XooNIpsUtilityUnzip extends XooNIpsUtility {
         unlink( $filepath );
       }
       while ( ! gzeof( $tfh ) && $size > 0 ) {
-        $buf = gzread( $tfh, min( $size, $unit ) );
+        $buf = gzread( $tfh, $unit );
         if ( $buf == '' || false === fwrite( $ofh, $buf ) ) {
           // maybe corrupt zip file
           fclose( $tfh );
