@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.17.2.1.2.21 $
+// $Revision: 1.17.2.1.2.22 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -46,6 +46,7 @@ include_once 'include/lib.php';
 include_once 'include/AL.php';
 include 'class/base/gtickets.php';
 
+$xgroup_handler =& xoonips_gethandler( 'xoonips', 'group' );
 
 $xnpsid = $_SESSION['XNPSID'];
 
@@ -119,7 +120,7 @@ if ( $result != RES_OK ){
 	exit;
 }
 if ( $index['open_level'] == OL_PUBLIC && xnp_is_moderator($xnpsid,$uid) ||
-     $index['open_level'] == OL_GROUP_ONLY && xnp_is_group_admin($xnpsid,$index['owner_gid'],$uid) ||
+     $index['open_level'] == OL_GROUP_ONLY && $xgroup_handler->isGroupAdmin( $uid, $index['owner_gid'] ) ||
      $index['open_level'] == OL_PRIVATE && $index['owner_uid'] == $uid ){
 	// User has the right to write.
 }
@@ -176,18 +177,6 @@ if( $result != RES_OK ){
     redirect_header( XOOPS_URL.'/', 3, "ERROR xnp_get_config_value can't get certify_item(result=$result)");
 }
 
-$group=array();
-if(xnp_is_group_admin($xnpsid,$index['owner_gid'],$uid)){
-	//get group name
-	$ret=xnp_get_group($xnpsid,$index['owner_gid'],$group);
-	if($ret!=RES_OK){
-	    redirect_header( XOOPS_URL.'/', 3, $res);
-	} else {
-	    $gid=$group['gid'];
-	    $group_name=$group['gname'];
-	}
-}
-
 $handler = xoops_gethandler('user');
 $user  = $handler->get($uid);
 $operation_user_name= $user->getVar('name');
@@ -522,7 +511,7 @@ $xoopsTpl->assign('limitLabel', $limitLabel );
 $xoopsTpl->assign('indexCount', $indexCount );
 $xoopsTpl->assign('indexNumberLimit', $indexNumberLimit );
 
-$xoopsTpl->assign('group_administrator',xnp_is_group_admin($xnpsid,$index['owner_gid'],$uid));
+$xoopsTpl->assign('group_administrator', $xgroup_handler->isGroupAdmin( $uid, $index['owner_gid'] ) );
 $xoopsTpl->assign('create_permission',
                   $index_handler->getPerm($xid, @$_SESSION['xoopsUserId'], 'create'));
 $xoopsTpl->assign('write_permission',
@@ -695,16 +684,19 @@ function xoonipsGetIndexCountInfo( $xnpsid, $xid ){
 		$limitLabel = _MD_XOONIPS_INDEX_NUMBER_OF_PRIVATE_INDEX_LABEL;
 	}
 	else if ( $openLevel == OL_GROUP_ONLY ){
+                $xgroup_handler =& xoonips_gethandler( 'xoonips', 'group' );
 		$indexGID = $index['owner_gid'];
-		$group = array();
-		$result = xnp_get_group( $xnpsid, $indexGID, $group );
-		
+                $xg_obj =& $xgroup_handler->getGroupObject( $indexGID );
+                if ( ! is_object( $xg_obj ) ) {
+                  redirect_header( XOOPS_URL.'/', 3, _MD_XOONIPS_ERROR_GROUP_SELECT );
+                  exit();
+                }
 		$indexCount = 0;
 		for ( $i = 0; $i < $indexesLen; $i++ ){
 			if ( $indexes[$i]['owner_gid'] == $indexGID )
 				$indexCount++;
 		}
-		$indexNumberLimit = $group['index_number_limit'];
+		$indexNumberLimit = $xg_obj->get( 'group_index_number_limit' );
 		$limitLabel = _MD_XOONIPS_INDEX_NUMBER_OF_GROUP_INDEX_LABEL;
 	}
 	else
