@@ -1,5 +1,5 @@
 <?php
-// $Revision: 1.1.4.1.2.32 $
+// $Revision: 1.1.4.1.2.33 $
 // ------------------------------------------------------------------------- //
 //  XooNIps - Neuroinformatics Base Platform System                          //
 //  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
@@ -360,30 +360,6 @@ function xoonips_deny_guest_access($url=null, $msg=_MD_XOONIPS_ITEM_FORBIDDEN)
     if( !$xoopsUser ) redirect_header( is_null($url) ? XOOPS_URL.'/modules/xoonips/user.php' : $url, 3, $msg );
 }
 
-/**
- *  get upload_max_filesize in bytes.
- *  'G' is converted to 1024*1024*1024 bytes.
- *  'M' is converted to 1024*1024 bytes.
- *  'K' is converted to 1024 bytes.
- *  
- *  @param $val string value of upload_max_filesize directive
- *  @return bytes
- */
-function xoonips_return_bytes($val) {
-   $val = trim($val);
-   $last = strtolower($val{strlen($val)-1});
-   switch($last) {
-       case 'g':
-           $val *= 1024;
-       case 'm':
-           $val *= 1024;
-       case 'k':
-           $val *= 1024;
-   }
-
-   return $val;
-}
-
 /**
  *
  * @brief convert lock type to string
