@@ -1,26 +1,29 @@
 <?php
-//  $Revision: 1.8 $                                                                  //
-//  --------------------------------------------------------------------------  //
-//  XooNIps Xoops modules for Neuroinformatics Platforms                        //
-//  Copyright (C) 2005 RIKEN, Japan. All rights reserved.                       //
-//  http://sourceforge.jp/projects/xoonips/                                     //
-//  --------------------------------------------------------------------------  //
-//  This program is free software; you can redistribute it and/or               //
-//  modify it under the terms of the GNU General Public License                 //
-//  as published by the Free Software Foundation; either version 2              //
-//  of the License, or (at your option) any later version.                      //
-//                                                                              //
-//  This program is distributed in the hope that it will be useful,             //
-//  but WITHOUT ANY WARRANTY; without even the implied warranty of              //
-//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               //
-//  GNU General Public License for more details.                                //
-//                                                                              //
-//  You should have received a copy of the GNU General Public License           //
-//  along with this program; if not, write to the Free Software                 //
-//  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA. //
-//  --------------------------------------------------------------------------  //
-
-include_once XOOPS_ROOT_PATH . '/modules/xoonips/condefs.php';
+// $Revision: 1.8.4.1.2.6 $
+// ------------------------------------------------------------------------- //
+//  XooNIps - Neuroinformatics Base Platform System                          //
+//  Copyright (C) 2005-2008 RIKEN, Japan All rights reserved.                //
+//  http://xoonips.sourceforge.jp/                                           //
+// ------------------------------------------------------------------------- //
+//  This program is free software; you can redistribute it and/or modify     //
+//  it under the terms of the GNU General Public License as published by     //
+//  the Free Software Foundation; either version 2 of the License, or        //
+//  (at your option) any later version.                                      //
+//                                                                           //
+//  You may not change or alter any portion of this comment or credits       //
+//  of supporting developers from this source code or any supporting         //
+//  source code which is considered copyrighted (c) material of the          //
+//  original comment or credit authors.                                      //
+//                                                                           //
+//  This program is distributed in the hope that it will be useful,          //
+//  but WITHOUT ANY WARRANTY; without even the implied warranty of           //
+//  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the            //
+//  GNU General Public License for more details.                             //
+//                                                                           //
+//  You should have received a copy of the GNU General Public License        //
+//  along with this program; if not, write to the Free Software              //
+//  Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307 USA //
+// ------------------------------------------------------------------------- //
 
 	/*
 		attributes add to index:
@@ -47,8 +50,6 @@ include_once XOOPS_ROOT_PATH . '/modules/xoonips/condefs.php';
 		for ( $i = 0; $i < $len; $i++ ){
 			$xid = $childFinder[$parentXID][$i];
 			
-			//echo "parent_xid,xid=($parentXID,$xid)<br>\n";
-			
 			$indexFinder[$xid]['is_last'] = ( $i == $len-1 );
 			$indexFinder[$xid]['depth'] = $depth;
 			
@@ -144,26 +145,41 @@ include_once XOOPS_ROOT_PATH . '/modules/xoonips/condefs.php';
 		return genIndexTree1( $indexes );
 	}
 	
-	function filterMyIndex( &$indexes, $xnpsid, $uid ){
-		$gids = array();
-		$result = xnp_get_groups_by_uid( $xnpsid, $uid, array(), $gids );
-		$gids = array_flip( $gids );
-		
-		$len = count($indexes);
-		for ( $i = 0; $i < $len; $i++ ){
-			$index = &$indexes[$i];
-			if ( $index === false ) continue;
-			if ( $index['open_level'] == OL_GROUP_ONLY ){
-				if ( !isset( $gids[ $index['owner_gid'] ] ) ) // group which he does not belong.
-				$indexes[$i] = false;
-			}
-			else if ( $index['open_level'] == OL_PRIVATE ){
-				if ( $index['owner_uid'] != $uid ) // index is not this user's one.
-				$indexes[$i] = false;
-			}
-		}
-	}
+function filterMyIndex( &$indexes, $xnpsid, $uid ){
+  $xgroup_handler =& xoonips_gethandler( 'xoonips', 'group' );
+  $gids = $xgroup_handler->getGroupIds( $uid, false );
+  $len = count( $indexes );
+  for ( $i = 0; $i < $len; $i++ ) {
+    $index =& $indexes[$i];
+    if ( $index === false ) {
+      continue;
+    }
+    if ( $index['open_level'] == OL_GROUP_ONLY ) {
+      if ( ! in_array( $index['owner_gid'], $gids ) ) {
+        // group which he does not belong.
+        $indexes[$i] = false;
+      }
+    } else if ( $index['open_level'] == OL_PRIVATE ) {
+      if ( $index['owner_uid'] != $uid ) {
+        // index is not this user's one.
+        $indexes[$i] = false;
+      }
+    }
+  }
+}
 	
+function filterPrivateIndex( &$indexes, $uid ) {
+  $len = count( $indexes );
+  for ( $i = 0; $i < $len; $i++ ) {
+    $index =& $indexes[$i];
+    if ( $index === false ) {
+      continue;
+    }
+    if ( $index['open_level'] != OL_PRIVATE ) {
+      $indexes[$i] = false;
+    }
+  }
+}
 	
 	/** get Index tree.
 	 *  get same index as $refIndex ($refIndex have same open_level and same owner_gid, and  same owner_uid)
@@ -209,65 +225,43 @@ include_once XOOPS_ROOT_PATH . '/modules/xoonips/condefs.php';
 	}
 	
 
-	function filterWritableIndex( &$indexes, $xnpsid, $uid ){
-		if ( xnp_is_moderator($xnpsid,$uid) )
-			return;
-		
-		$isGroupAdmin = array();
-		$criteria = array();
-		$gids = array();
-		$result = xnp_get_groups_by_uid( $xnpsid, $uid, $criteria, $gids );
-		if ( $result == RES_OK ){
-			foreach ( $gids as $key => $gid ){
-				if ( xnp_is_group_admin( $xnpsid, (int)$gid, $uid ) )
-					$isGroupAdmin[(int)$gid] = true;
-			}
-		}
-		
-		$len = count($indexes);
-		for ( $i = 0; $i < $len; $i++ ){
-			$index = &$indexes[$i];
-			if ( $index === false ) continue;
-			if ( !( $index['open_level'] == OL_PRIVATE && $index['owner_uid'] == $uid
-			  || $index['open_level'] == OL_GROUP_ONLY && isset($isGroupAdmin[$index['owner_gid']]) ) )
-				$indexes[$i] = false;
-		}
-	}
+function filterWritableIndex( &$indexes, $xnpsid, $uid ){
+  $xmember_handler =& xoonips_gethandler( 'xoonips', 'member' );
+  $xgroup_handler =& xoonips_gethandler( 'xoonips', 'group' );
+  if ( $xmember_handler->isModerator( $uid ) ) {
+    return;
+  }
+  $admin_gids = $xgroup_handler->getGroupIds( $uid, true );
+  $len = count($indexes);
+  for ( $i = 0; $i < $len; $i++ ) {
+    $index =& $indexes[$i];
+    if ( $index === false ) {
+      continue;
+    }
+    if ( ! ( $index['open_level'] == OL_PRIVATE && $index['owner_uid'] == $uid
+             || $index['open_level'] == OL_GROUP_ONLY && in_array( $index['owner_gid'], $admin_gids ) ) ) {
+      $indexes[$i] = false;
+    }
+  }
+}
 	
-	// get editable Index in editindex.php.
-	function filterEditableIndex( &$indexes, $xnpsid, $uid, $puid, $isPublicEditable ){
-		$isPublicEditable |= xnp_is_moderator($xnpsid,$uid);
-		$isGroupAdmin = array();
-		$criteria = array();
-		$gids = array();
-		$result = xnp_get_groups_by_uid( $xnpsid, $puid, $criteria, $gids );
-		if ( $result == RES_OK ){
-			foreach ( $gids as $key => $gid ){
-				if ( xnp_is_group_admin( $xnpsid, (int)$gid, $puid ) )
-					$isGroupAdmin[(int)$gid] = true;
-			}
-		}
-		
-		$len = count($indexes);
-		for ( $i = 0; $i < $len; $i++ ){
-			$index = &$indexes[$i];
-			if ( $index === false ) continue;
-			if (!( $index['open_level'] == OL_PRIVATE && $index['owner_uid'] == $puid
-			  || $index['open_level'] == OL_GROUP_ONLY && isset($isGroupAdmin[$index['owner_gid']])
-			  || $index['open_level'] == OL_PUBLIC && $isPublicEditable ))
-				$indexes[$i] = false;
-		}
-	}
-	
-	function filterNonbinderIndex( &$indexes ){
-		$len = count($indexes);
-		for ( $i = 0; $i < $len; $i++ ){
-			if ( $indexes[$i] === false ) continue;
-			if ( $indexes[$i]['item_id'] == IID_BINDERS )
-				$indexes[$i] = false;
-		}
-	}
-	
-
-
+// get editable Index in editindex.php.
+function filterEditableIndex( &$indexes, $xnpsid, $uid, $puid, $isPublicEditable ){
+  $xmember_handler =& xoonips_gethandler( 'xoonips', 'member' );
+  $xgroup_handler =& xoonips_gethandler( 'xoonips', 'group' );
+  $isPublicEditable |= $xmember_handler->isModerator( $uid );
+  $admin_gids = $xgroup_handler->getGroupIds( $puid, true );
+  $len = count($indexes);
+  for ( $i = 0; $i < $len; $i++ ) {
+    $index =& $indexes[$i];
+    if ( $index === false ) {
+      continue;
+    }
+    if ( ! ( $index['open_level'] == OL_PRIVATE && $index['owner_uid'] == $puid
+             || $index['open_level'] == OL_GROUP_ONLY && in_array( $index['owner_gid'], $admin_gids )
+             || $index['open_level'] == OL_PUBLIC && $isPublicEditable ) ) {
+      $indexes[$i] = false;
+    }
+  }
+}
 ?>
